/**
 * Represents database connection configuration. It can be a URI string or object.
 */
export declare type SeederDatabaseConfig = string | SeederDatabaseConfigObject;
/**
 * Defines configuration for Database connection in a form of an object.
 */
export interface SeederDatabaseConfigObject {
    /**
     * Database connection protocol
     */
    protocol: string;
    /**
     * Database connection host
     */
    host: string;
    /**
     * Database connection port
     */
    port: number;
    /**
     * Database name.
     */
    name: string;
    /**
     * Database Username.
     */
    username?: string;
    /**
     * Database password.
     */
    password?: string;
    /**
     * Options for MongoDB Database Connection URI.
     * Read more on: https://docs.mongodb.com/manual/reference/connection-string.
     */
    options?: SeederDatabaseConfigObjectOptions;
}
/**
 * Defines options for MongoDB Database Connection URI.
 * Read more on: https://docs.mongodb.com/manual/reference/connection-string.
 */
export interface SeederDatabaseConfigObjectOptions {
    [key: string]: string;
}
/**
 * Stores default values for database connection.
 */
export declare const defaultDatabaseConfigObject: SeederDatabaseConfigObject;
/**
 * Checks if an object is valid database connection configuration.
 *
 * @param object Input object
 */
export declare function isSeederDatabaseConfigObject(object: any): object is SeederDatabaseConfigObject;
